CaptchaFormField class

Inheritance

Constructors

CaptchaFormField({Key? key, int captchaLength = 6, Duration captchaDuration = const Duration(minutes: 1), String? labelText = 'CAPTCHA', InputDecoration? inputDecoration, dynamic onChanged(String)?, String? validator(String? input, String generatedCaptcha)?, CaptchaComplexity captchaComplexity = CaptchaComplexity.medium, BoxDecoration? captchaBackground, TextStyle? captchaTextStyle, ThemeData? captchaTheme, String? requiredErrorMessage, String? mismatchErrorMessage})
const

Properties

captchaBackground BoxDecoration?
final
captchaComplexity CaptchaComplexity
final
captchaDuration Duration
final
captchaLength int
final
captchaTextStyle TextStyle?
final
captchaTheme ThemeData?
final
hashCode int
The hash code for this object.
no setterinherited
inputDecoration InputDecoration?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelText String?
final
mismatchErrorMessage String?
final
onChanged → dynamic Function(String)?
final
requiredErrorMessage String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validator String? Function(String? input, String generatedCaptcha)?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<CaptchaFormField>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited