validator property
A validator function to check the input against the generated CAPTCHA.
Defaults to a function that checks if the input matches the CAPTCHA.
Implementation
final String? Function(String? input, String generatedCaptcha)? validator;
A validator function to check the input against the generated CAPTCHA.
Defaults to a function that checks if the input matches the CAPTCHA.
final String? Function(String? input, String generatedCaptcha)? validator;